/*
 * Copyright (c) 2011 J. Lewis Muir <jlmuir@imca.aps.anl.gov>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package imcacat.jaccordion;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.awt.Color;
import java.awt.Component;
import java.awt.Font;

import javax.swing.JLabel;
import javax.swing.SwingUtilities;

import org.junit.Test;

/**
 * I test <code>JClosablePanel</code>.
 */
public class JClosablePanelTest {
  @Test
  public void testConstructor01() throws Exception {
    SwingUtilities.invokeAndWait(new Runnable() {
      @Override
      public void run() {
        String title = "Ships";
        Component body = new JLabel("Millennium Falcon");
        JClosablePanel panel = new JClosablePanel(title, body);
        assertEquals(title, panel.getTitle());
        assertEquals(body, panel.getBody());
        assertFalse(panel.isOpen());
      }
    });
  }

  @Test
  public void testOpen01() throws Exception {
    SwingUtilities.invokeAndWait(new Runnable() {
      @Override
      public void run() {
        JClosablePanel panel = new JClosablePanel("Ships", new JLabel("Millennium Falcon"));
        panel.makeOpen();
        assertTrue(panel.isOpen());
        assertTrue(panel.getBody().isVisible());
        panel.makeClosed();
        assertFalse(panel.isOpen());
        panel.toggleOpen();
        assertTrue(panel.isOpen());
        panel.toggleOpen();
        assertFalse(panel.isOpen());
        panel.setOpen(true);
        assertTrue(panel.isOpen());
        panel.setOpen(false);
        assertFalse(panel.isOpen());
      }
    });
  }

  @Test
  public void testSetHeaderBackground01() throws Exception {
    SwingUtilities.invokeAndWait(new Runnable() {
      @Override
      public void run() {
        JClosablePanel panel = new JClosablePanel("Ships", new JLabel("Millennium Falcon"));
        panel.setHeaderBackground(Color.GREEN);
        assertEquals(Color.GREEN, panel.getHeaderBackground());
      }
    });
  }

  @Test
  public void testSetHeaderForekground01() throws Exception {
    SwingUtilities.invokeAndWait(new Runnable() {
      @Override
      public void run() {
        JClosablePanel panel = new JClosablePanel("Ships", new JLabel("Millennium Falcon"));
        panel.setHeaderForeground(Color.RED);
        assertEquals(Color.RED, panel.getHeaderForeground());
      }
    });
  }

  @Test
  public void testSetTitleFont01() throws Exception {
    SwingUtilities.invokeAndWait(new Runnable() {
      @Override
      public void run() {
        JClosablePanel panel = new JClosablePanel("Ships", new JLabel("Millennium Falcon"));
        Font italicFont = panel.getTitleFont().deriveFont(Font.ITALIC);
        panel.setTitleFont(italicFont);
        assertEquals(italicFont, panel.getTitleFont());
      }
    });
  }
}
